function [R,B,A] = ConfigureADF9010PLL(Fout, Fspace, Fref, P)
% Given the desired output frequency (Fout), the spacing between
% frequencies (Fspace, e.g., 860e6), the external reference frequency (Fref, e.g., 20e6) and the
% VCO output pre-scaler (P), this function returns the values to be programmed into 
% the PLL configuration parameters R (Reference counter), B (B counter) and 
% A (A counter) for the correct output frequency.
% Note: for ADF9010, Fvco = 4*Fout --> for Fout = 840 MHz - 960 MHz --> Fvco = 3360 MHz - 3840 MHz  
% See datasheet of ADF9010 for details. 

    if (mod(Fref,Fspace)~=0)
        fprintf('Fref should be a multiple of Fspace\n')
        R=0;
    else
        R=Fref/Fspace;
    end
    if (mod(Fout,Fspace)~=0)
        fprintf('Fout should be a multiple of Fspace\n')
        A=0;
        B=0;
    else
        N=Fout/Fspace;
        B=floor(N/P);
    
        A=N-B*P;
        
        if (B>=A)
           fprintf('B > A --> OK\n')
        else
           fprintf('B must be greater than or equal to A\n');
        end
        if (N>=P^2-P)
           fprintf('N > P^2-P --> OK\n')
        else
           fprintf('Continuously adjacent frequencies cannot be generated\n')
        end
    end
end